﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using PropertyChanged;

namespace DataEntity
{
    [AddINotifyPropertyChangedInterface]
    [Table ("Materialy")]

    public partial class Material : BaseModel
    {
        [Key]  // přiřazení primárního klíče
        [Column (Order = 1)]  // sloupec na prvním místě
        public int MaterialId { get; set; }  //primární klíč, typu int



        [Required (ErrorMessage = "Název materiálu je povinné pole")]
        [StringLength (255, ErrorMessage = "Délka nesmí přesáhnout 255 znaků")]
        public string NazevMat { get; set; } //get, set tzv. Getter, Setter

        /// <summary>
        /// Pojistné množství
        /// </summary>
        [Required(ErrorMessage = "Pojistné množství je povinné pole")]
        [Range (0, int.MaxValue, ErrorMessage = "Pojistné množství musí být celé kladné číslo.") ]

        public int MnozPoj { get; set; }

        [Required(ErrorMessage = "Množství do palety je povinné pole")]
        [Range(0, int.MaxValue, ErrorMessage = "Množství do palety musí být celé kladné číslo.")]
        public int MnozPal { get; set; }

        public string Komentar { get; set; }

        [Required(ErrorMessage = "Datum je povinné pole")]
        [Column (TypeName="date")]
        public DateTime Datum { get; set; }

        public int MernaJednotkaId { get; set; }

        [ForeignKey(nameof(MernaJednotkaId))]
        public virtual MernaJednotka MernaJednotka { get; set; }

        public virtual ObservableCollection<Paleta> Palety { get; set; }


        //počítaná pole
        
        public int CelkoveMnozstvi
        {
            get
            {
                if (Palety==null)
                {
                    return 0;
                }
                else
                {
                    return Palety.Sum(x => x.MnozPa);
                }
            }
        }

        public bool PodPojistnymMnozstvim
        {
            get
            {
                return CelkoveMnozstvi < MnozPoj;
            }
        }


        //public int Vstup (Paleta pal)
        //{
        //    return pal.MnozPa;
        //}

        // public int CelkoveMnozstvi2 => Palety==null ? 0 : Palety.Sum(x => x.MnozPa);


    }
}
